==> simple-jndi-0.13.0-sources.jar: org/osjava/sj/loader/convert/MapConverter.java <==
/*
 * Copyright (c) 2005, Henri Yandell
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or 
 * without modification, are permitted provided that the 
 * following conditions are met:
 * 
 * + Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * 
 * + Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * 
 * + Neither the name of Simple-JNDI nor the names of its contributors 
 *   may be used to endorse or promote products derived from this software 
 *   without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.osjava.sj.loader.convert;

import java.util.Map;
import java.util.Iterator;
import java.util.Properties;

public class MapConverter implements Converter {

    public Object convert(Properties properties, String type) {
        if("java.util.Map".equals(type)) {
            type = "java.util.HashMap";
        } else 
        if("java.util.Properties".equals(type)) {
            return properties;
        }
        try {
            Class c = Class.forName(type);
            Map m = (Map) c.newInstance();

            Iterator entries = properties.entrySet().iterator();
            while(entries.hasNext()) {
                Map.Entry entry = (Map.Entry) entries.next();
                m.put( entry.getKey(), entry.getValue() );
            }

            return m;
        } catch(ClassNotFoundException cnfe) {
            throw new RuntimeException("Unable to find class: "+type, cnfe);
        } catch(InstantiationException ie) {
            throw new RuntimeException("Unable to instantiate class: "+type, ie);
        } catch(IllegalAccessException ie) {
            throw new RuntimeException("Unable to access class: "+type, ie);
        }

    }

}

==> simple-jndi-0.15.0-sources.jar: org/osjava/sj/loader/convert/MapConverter.java <==
/*
 * Copyright (c) 2005, Henri Yandell
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or 
 * without modification, are permitted provided that the 
 * following conditions are met:
 * 
 * + Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * 
 * + Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * 
 * + Neither the name of Simple-JNDI nor the names of its contributors 
 *   may be used to endorse or promote products derived from this software 
 *   without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.osjava.sj.loader.convert;

import java.util.Iterator;
import java.util.Map;
import java.util.Properties;

public class MapConverter implements ConverterIF {

    public Object convert(Properties properties, String type) {
        if("java.util.Map".equals(type)) {
            type = "java.util.HashMap";
        } else 
        if("java.util.Properties".equals(type)) {
            return properties;
        }
        try {
            Class c = Class.forName(type);
            Map m = (Map) c.newInstance();

            Iterator entries = properties.entrySet().iterator();
            while(entries.hasNext()) {
                Map.Entry entry = (Map.Entry) entries.next();
                m.put( entry.getKey(), entry.getValue() );
            }

            return m;
        } catch(ClassNotFoundException cnfe) {
            throw new RuntimeException("Unable to find class: "+type, cnfe);
        } catch(InstantiationException ie) {
            throw new RuntimeException("Unable to instantiate class: "+type, ie);
        } catch(IllegalAccessException ie) {
            throw new RuntimeException("Unable to access class: "+type, ie);
        }

    }

}
